/*Copyright (C) 2019 Centro de Computacao Cientifica e Software Livre
Departamento de Informatica - Universidade Federal do Parana

This file is part of Plataforma Integrada MEC.

Plataforma Integrada MEC is free software: you can redistribute it and/or modify
it under the terms of the GNU Affero General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

Plataforma Integrada MEC is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU Affero General Public License for more details.

You should have received a copy of the GNU Affero General Public License
along with Plataforma Integrada MEC.  If not, see <http://www.gnu.org/licenses/>.*/
import React, { useState } from "react";
import Card from "@material-ui/core/Card";
import CardContent from "@material-ui/core/CardContent";
import CardActions from "@material-ui/core/CardActions";
import Typography from "@material-ui/core/Typography";
import Button from "@material-ui/core/Button";
import ListRoundedIcon from "@material-ui/icons/ListRounded";
import ButtonGroup from "@material-ui/core/ButtonGroup";
import DeleteRoundedIcon from "@material-ui/icons/DeleteRounded";
import EditRoundedIcon from "@material-ui/icons/EditRounded";
import UpdateRoundedIcon from "@material-ui/icons/UpdateRounded";
import SaveIcon from "@material-ui/icons/Save";
import ArrowBackIosIcon from "@material-ui/icons/ArrowBackIos";
import { useStyles } from "../Styles/DataCard";

const DataCard = (props) => {
    const classes = useStyles();
    const [edit, setEdit] = useState(false);

    const buttonArr = [
        {
            label: "Listar",
            icon: <ListRoundedIcon />,
        },
        edit
            ? {
                label: "Voltar",
                icon: <ArrowBackIosIcon />,
            }
            : {
                label: "Editar",
                icon: <EditRoundedIcon />,
            },
        {
            label: "Deletar",
            icon: <DeleteRoundedIcon />,
        },
        {
            label: "Atualizar",
            icon: <UpdateRoundedIcon />,
        },
    ];

    //Change state of the var edit
    const EditHandler = () => {
        setEdit(!edit);
    };

    // it stores an function that will be called when a button is clicked
    const functionArr = [props.viewData, EditHandler];

    return (
        edit ?
            <Card className={classes.root} variant="outlined">
                <CardContent>
                    <div className={classes.displayRow}>
                        <Typography
                            className={classes.title}
                            color="inherit"
                            gutterBottom
                        >
                            {props.data[1].prop}
                        </Typography>
                        <ButtonGroup
                            color="primary"
                            aria-label="outlined primary button group"
                        >
                            {buttonArr.map((button, index) => (
                                <Button onClick={functionArr[index]}>
                                    <div className={classes.displayRow}>
                                        {button.icon}
                                        {button.label}
                                    </div>
                                </Button>
                            ))}
                        </ButtonGroup>
                    </div>
                    
                    {/* Display the edit area */}
                    {props.component} 

                </CardContent>
            </Card>
            :
            <Card className={classes.root} variant="outlined">
                <CardContent>
                    <div className={classes.displayRow}>
                        <Typography
                            className={classes.title}
                            color="inherit"
                            gutterBottom
                        >
                            {props.data[1].prop}
                        </Typography>
                        <ButtonGroup
                            color="primary"
                            aria-label="outlined primary button group"
                        >
                            {buttonArr.map((button, index) => (
                                <Button onClick={functionArr[index]}>
                                    <div className={classes.displayRow}>
                                        {button.icon}
                                        {button.label}
                                    </div>
                                </Button>
                            ))}
                        </ButtonGroup>
                    </div>
                    {props.data.map((info , index) => (
                        <div className={classes.displayColumn} key={index}>
                            <Typography color="initial" className={classes.subTitle}>
                                {info.subTitle}
                            </Typography>
                            <Typography color='textSecondary'>
                                {
                                    info.prop === null ? 'Sem dados' : info.prop
                                }
                            </Typography>
                        </div>
                    ))}
                </CardContent>
            </Card>
    );
}

export default DataCard;
